<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>Widok podstawowy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>Pobierz listę</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>Adres wideo:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Kod formatu</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>rozszerzenie</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>rozdzielczość</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>uwagi</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Silnik:</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>Wklej zawartość schowka</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>Ostatnio używane</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>Zapisz opcje pobierania</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>Pobieranie masowe</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Miniaturka</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>Adres pliku wideo</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation></translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>Monitoruj zawartość schowka</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>Dodaj adres do listy</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>Pobieranie playlisty</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>Opcje pobierania:</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>podaj adres playlisty:</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>Wyczyść archiwum</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>Użyj archiwum</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Biblioteka</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>W górę</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Otwórz katalog</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Katalog domyślny</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Konfiguracja</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>Opcje ogólne</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>Pokaż ikonę w trayu</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>Automatycznie zapisz listę niepobranych mediów</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>Ustawienia domyślne</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Ustaw domyślne</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Ustawienia formatów</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>Katalog pobieranych plików</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>Wybierz język</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>Domyślne opcje silnika</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Opcje pobierania listy:</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Subskrypcje</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>Włącz zakładkę z biblioteką</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Kodowanie tekstu</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>Silnik</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Domyślne</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>Dodatkowe parametry</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>Manadżer adresów</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Opcje pobierania</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>Przypisz silniki do adresów</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>Filtr adresów</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Engine Name:</source>
        <translation>Silnik:</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>Odpowiedź dla</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>Zapisz napisy do pliku</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>Wczytaj listę z pliku</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Ustawienia formatów</translation>
    </message>
    <message>
        <source>%1 Preset Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>Otwórz katalog z pobranymi plikami</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>Plik z rozszerzeniem &quot;.txt&quot; będzie zawierał jedynie adresy</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation type="unfinished">Kopiuj adres</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>Zapisz listę do pliku</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Prawa autorskie</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Wersja Qt</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translatorcomment>http://gnu.org.pl/text/licencja-gnu.html</translatorcomment>
        <translation>Niniejszy program jest wolnym oprogramowaniem; możesz go rozprowadzać dalej i/lub modyfikować na warunkach Powszechnej Licencji Publicznej GNU, wydanej przez Fundację Wolnego Oprogramowania - według wersji 2-giej tej Licencji lub którejś z późniejszych wersji.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translatorcomment>http://gnu.org.pl/text/licencja-gnu.html</translatorcomment>
        <translation>Niniejszy program rozpowszechniany jest z nadzieją, iż będzie on użyteczny - jednak BEZ JAKIEJKOLWIEK GWARANCJI, nawet domyślnej gwarancji PRZYDATNOŚCI HANDLOWEJ albo PRZYDATNOŚCI DO OKREŚLONYCH ZASTOSOWAŃ. W celu uzyskania bliższych informacji - Powszechna Licencja Publiczna GNU.</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>angielski (USA)</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>hiszpański (Hiszpania)</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>chiński (Chiny)</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>turecki (Turcja)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>rosyjski (Rosja)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>japoński (Japonia)</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>francuski (Francja)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>włoski (Włochy)</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>szwedzki (Szwecja)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>Niemiecki (Niemcy)</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>polski (Polska)</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>Błąd, plik wykonywalny &quot;%1&quot; nie został znaleziony</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>Silnik &quot;%1&quot; wymaga aplikacji Media Downloader w wersji &quot;%2&quot; lub wyższej</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>Aby wyłączyć te powiadomienia:-</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>Przejdź do zakładki &quot;konfiguracja&quot;.</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>Przejdź do zakładki &quot;opcje ogólne&quot;.</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>Błąd parsowania pliku konfiguracyjnego &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>Niepowodzenie podczas ładowania wtyczki</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>Nie udało się zlokalizować pliku wykonywalnego &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>Nie udało się zlokalizować interpretera python3 dla backendu &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>Pobieranie przerwane</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Kod formatu</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>rozszerzenie</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>rozdzielczość</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note</source>
        <translation>uwagi</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>Błąd podczas zapisu do pliku</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>Błąd podczas odczytu pliku</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>Czas:</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>Nie udało się ustalić wersji programu &quot;%1&quot;. Upewnij się, że jest zainstalowany i działa poprawnie</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>Brak odpowiedzi z sieci przez %1 sekund</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>Nieudane pobieranie, błąd podczas tworzenia ścieżki: </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>Rozpocznij pobieranie</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>Błąd podczas pobierania</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Nieudane parsowanie pliku json z gihuba</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Ścieżka docelowa</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>Pobieranie zakończone</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>Wypakowywanie archiwum: </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Przetwarzanie</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>Poberanie zakończone</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>Zmiana katalogu pobierania na domyślny</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>Post processing</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>Wymuś pobieranie</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>Pokaż logi</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>Data opublikowania:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Czas trwania:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>Napisy</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Opcje pobierania</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>Dodatkowe opcje pobierania</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>Czas pobierania</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>Plik znajduje się już w archiwum</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Ciemny</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metoda</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation type="unfinished">To może potrwać bardzo długo</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>Wybierz plik</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>Pobieranie komentarzy</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Kopiuj adres</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>Pokaż napisy</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Pokaż komentarze</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>Pokaż opcje</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>Pobierz multimedia</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>Pobieranie napisów</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>Ustaw jako domyślne</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>Wybierz plik silnika</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>Wybierz katalog pobieranych plików</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">Dodaj</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation type="unfinished">Ustaw domyślne</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Anuluj</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Usuń wszystko</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Anuluj</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>Logi</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Opcje pobierania listy:</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Kopiuj adres</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Pokaż komentarze</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>Pokaż wszystkie zaktualizowane</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>Pobierz wszystkie zaktualizowane</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>Zarządzaj subskrypcjami</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>Liczba pobranych stron</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>Pobieranie informacji o pliku wideo</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>To może potrwać bardzo długo</translation>
    </message>
</context>
</TS>
